@@ -424,8 +424,8 @@ class Transform(GrazingGeometry):
         if int2d:
             gi_lut = splitBBoxLUT.HistoBBox2d(pos0, dpos0, pos1, dpos1,
                                               bins=npt,
-                                              pos0Range=pos0Range,
-                                              pos1Range=pos1Range,
+                                              pos0_range=pos0Range,
+                                              pos1_range=pos1Range,
                                               mask=mask,
                                               mask_checksum=mask_checksum,
                                               allow_pos0_neg=True,
@@ -433,8 +433,8 @@ class Transform(GrazingGeometry):
         else:
             gi_lut = splitBBoxLUT.HistoBBox1d(pos0, dpos0, pos1, dpos1,
                                               bins=npt,
-                                              pos0Range=pos0Range,
-                                              pos1Range=pos1Range,
+                                              pos0_range=pos0Range,
+                                              pos1_range=pos1Range,
                                               mask=mask,
                                               mask_checksum=mask_checksum,
                                               allow_pos0_neg=True,
@@ -498,8 +498,8 @@ class Transform(GrazingGeometry):
         if int2d:
             gi_lut = splitBBoxLUT.HistoBBox2d(pos0, dpos0, pos1, dpos1,
                                               bins=npt,
-                                              pos0Range=pos0Range,
-                                              pos1Range=pos1Range,
+                                              pos0_range=pos0Range,
+                                              pos1_range=pos1Range,
                                               mask=mask,
                                               mask_checksum=mask_checksum,
                                               allow_pos0_neg=True,
@@ -507,8 +507,8 @@ class Transform(GrazingGeometry):
         else:
             gi_lut = splitBBoxLUT.HistoBBox1d(pos0, dpos0, pos1, dpos1,
                                               bins=npt,
-                                              pos0Range=pos0Range,
-                                              pos1Range=pos1Range,
+                                              pos0_range=pos0Range,
+                                              pos1_range=pos1Range,
                                               mask=mask,
                                               mask_checksum=mask_checksum,
                                               allow_pos0_neg=True,
@@ -1007,8 +1007,8 @@ class Transform(GrazingGeometry):
                     pos=pos,
                     weights=data,
                     bins=npt,
-                    pos0Range=x_range,
-                    pos1Range=y_range,
+                    pos0_range=x_range,
+                    pos1_range=y_range,
                     dummy=dummy,
                     delta_dummy=delta_dummy,
                     mask=mask, dark=dark, flat=flat,
@@ -1036,8 +1036,8 @@ class Transform(GrazingGeometry):
                     pos1=pos1,
                     delta_pos1=dpos1,
                     bins=npt,
-                    pos0Range=x_range,
-                    pos1Range=y_range,
+                    pos0_range=x_range,
+                    pos1_range=y_range,
                     dummy=dummy,
                     delta_dummy=delta_dummy,
                     mask=mask, dark=dark, flat=flat,
@@ -1625,8 +1625,8 @@ class Transform(GrazingGeometry):
                     pos=pos,
                     weights=data,
                     bins=npt,
-                    pos0Range=p0_range,
-                    pos1Range=p1_range,
+                    pos0_range=p0_range,
+                    pos1_range=p1_range,
                     dummy=dummy,
                     delta_dummy=delta_dummy,
                     mask=mask,
@@ -1643,8 +1643,8 @@ class Transform(GrazingGeometry):
                         pos=pos,
                         weights=variance,
                         bins=npt,
-                        pos0Range=p0_range,
-                        pos1Range=p1_range,
+                        pos0_range=p0_range,
+                        pos1_range=p1_range,
                         dummy=dummy,
                         delta_dummy=delta_dummy,
                         mask=mask)
@@ -1671,8 +1671,8 @@ class Transform(GrazingGeometry):
                     pos1=chi,
                     delta_pos1=dchi,
                     bins=npt,
-                    pos0Range=p0_range,
-                    pos1Range=p1_range,
+                    pos0_range=p0_range,
+                    pos1_range=p1_range,
                     dummy=dummy,
                     delta_dummy=delta_dummy,
                     mask=mask,
@@ -1691,8 +1691,8 @@ class Transform(GrazingGeometry):
                         pos1=chi,
                         delta_pos1=dchi,
                         bins=npt,
-                        pos0Range=p0_range,
-                        pos1Range=p1_range,
+                        pos0_range=p0_range,
+                        pos1_range=p1_range,
                         dummy=dummy,
                         delta_dummy=delta_dummy,
                         mask=mask)
